@@ -15,7 +15,9 @@ import multiprocessing
 import threading
 from goto import with_goto # pip3 install goto_statement
 import subprocess
-sys.path.append("../server/modules")
+BASE_DIR = os.path.dirname(os.path.abspath(__file__))
+sys.path.append(BASE_DIR)
+sys.path.append(os.path.join(BASE_DIR,"../server/modules"))
 import board_manager
 import log
 from log import RunningLog
