@@ -7,9 +7,11 @@ import socket
 import ast
 import multiprocessing
 import threading
-import save_task
 import datetime
 from multiprocessing.managers import BaseManager
+BASE_DIR = os.path.dirname(os.path.abspath(__file__))
+sys.path.append(BASE_DIR)
+import save_task
 from modules import board_manager
 from modules import queuelib
 from modules import log
