@@ -4,12 +4,14 @@ import socket
 import threading
 import time
 import json
-import sendmsg
 import copy
 import argparse
+from getopt import getopt
+BASE_DIR = os.path.dirname(os.path.abspath(__file__))
+sys.path.append(BASE_DIR)
+import sendmsg
 import ftp
 import msg
-from getopt import getopt
 
 class CmdBase(object):
     def __init__(self):
